### Use

#### method 1
`index.js`:
```javascript
    // Global Registration
    // import with ES6
    import Vue from 'vue'
    import markdownEditorVue from 'markdown-editer-vue'
    import 'markdown-editer-vue/dist/css/index.css'

    // use
    Vue.use(markdownEditorVue)
    new Vue({
        'el': '#main',
        data() {
            return { value: '' }
        }
    })
```
`index.html`
```html
// The same below
<div id="main">
    <markdown-editer-vue v-model="value"/>
</div>
```

#### method 2
`index.js`:
```javascript
    // Global Registration
    // require with Webpack/Node.js
    ...
    var markdownEditorVue = require('markdown-editer-vue')
    import 'markdown-editer-vue/dist/css/index.css'

    ...
```

#### method 3
`editor.vue`:
```javascript
    <template>
        <div id="editor">
            <markdown-editer-vue style="height: 100%"></markdown-editer-vue>
        </div>
    </template>
    <script>
    // Local Registration
    import { markdownEditorVue } from 'markdown-editer-vue'
    import 'markdown-editer-vue/dist/css/index.css'
    export default {
        name: 'editor',
        components: {
            markdownEditorVue
            // or 'markdown-editer-vue': markdownEditorVue
        }
    }
    </script>
    <style>
    #editor {
        margin: auto;
        width: 80%;
        height: 580px;
    }
    </style>
```
`index.js`:
```javascript
	// The same below
    import Vue from 'vue';
    var editor = require('./editor.vue');
    new Vue({
        el: '#main',
        render: h => h(editor)
    });
```
`index.html`:
```html
// The same below
<div id="main">
</div>
```

#### method 4
`editor.vue`:
```javascript
    ...
    <script>
    // Local Registration
    // import markdownEditorVue from 'markdown-editer-vue'
    var markdownEditorVue = require('markdown-editer-vue')
	// the Object of markdown-it : markdownEditorVue.markdownIt
    import 'markdown-editer-vue/dist/css/index.css'
    export default {
        name: 'editor',
        components: {
            'markdown-editer-vue': markdownEditorVue.markdownEditorVue
        }
    }
    </script>
    <style>
    ...
    </style>
```